@@ -1615,7 +1615,7 @@ class Update(MethodsInterface):
         if not retval:
             if actual_reason is self.Reason.LevelWrong:
                 #TODO translate
-                raise UpdateError(_("Failed to find the reliable server with appropriate level"))
+                raise UpdateError(_("Failed to find trusted server with current level"))
             elif actual_reason is self.Reason.BadSign:
                 raise UpdateError(_("Failed to find the reliable server with appropriate updates"))
             elif actual_reason in (self.Reason.Outdated,
@@ -1687,7 +1687,7 @@ class Update(MethodsInterface):
                         self.set_migration_mode(True)
                     #TODO translate
                     raise UpdateError(
-                        _("Current binhost {} has a wrong update level. Current level: {} Binhost level: {}").\
+                        _("Current binhost {} has wrong update level. Current level: {} Binhost level: {}").\
                                 format(binhost_url, self.clVars.Get("update.cl_update_level"), binhost.level, ))
 
         if self.binhosts_data.gpg:
@@ -1765,7 +1765,7 @@ class Update(MethodsInterface):
 
     #нужен так как detect_best_binhost не essential, ошибка не останавливает 
     def interrupt_on_no_leveled_binhost(self):
-        raise UpdateError(_("Failed to find binhost with level equal or higher than local level"))
+        raise UpdateError(_("Failed to find binhost with level equal to or higher than local level"))
 
     def set_migration_mode(self, val=True):
         val_to_write = Variable.On if val else Variable.Off
@@ -1800,7 +1800,7 @@ class Update(MethodsInterface):
             migr_binhost_data or Variable.EmptyTable, force=True)
         if not (migr_binhost_data):
             #TODO translate
-            raise UpdateError(_("Failed to find the working migration server with appropriate level"))
+            raise UpdateError(_("Failed to find working migration host with current level"))
         self.endTask()
         return True
 
